@@ -35,7 +35,7 @@ def read_json(filepath):
     Returns:
         JSON: JSON file
     """
-    with open('annotated_for_appen.json') as f:
+    with open(filepath) as f:
         return json.load(f)
 
 
