@@ -6,6 +6,10 @@ from pytz import timezone
 import dateutil.parser
 
 
+def time_start():
+    return timeit.default_timer()
+
+
 def timer(time_start, length=1):
     """Returns time elapsed time in minutes and time per unit.
 
